%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|sed -e 's/EL.*$/EL/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | sed -e 's/.*EL//g' | sed -e 's/^$/up/g')}}

# On RHEL 3, up type has no tag
%if "%{type}" != "up"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%endif

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmblock'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,rhel,3
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-pmwv.pl --os=linux,rhel,3 --release %{kernel_dir} --rpmBuild 913593 --modKey %{modKey}
%define kmp_version %version

Name:         vmware-tools-vmblock
BuildRequires: kernel-source gcc
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmblock kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.1.2.0
Release:      1.el3
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vmblock-configModule.tar.gz

Source0:      vmblock.tar

%prep
%setup -n vmblock-only

%build
make clean
make

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
# The following command copies our newly build kernel module to a known
# location.  Unfortunately sometimes the kmod source build places the kmods
# in inconsistent locations.
if [ -e ../vmblock.o ]; then
   cp -v ../vmblock.o .
fi
if [ -e driver-%{kernel_dir}/vmblock-xxx-%{kernel_dir} ]; then
   cp -v driver-%{kernel_dir}/vmblock-xxx-%{kernel_dir} ./vmblock.o
fi

# Install kernel module
install -m 644 -D vmblock.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/%{name}/vmblock.o

# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmblock.  The vmblock module is used by vmware-user to block file access to files that are in the process of being copied from host to guest or guest to host (such as a drag and drop operation between a host and a guest).

%package common
Summary:      Contains the common files used by all the vmblock kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.10
Release:      1.el3
Version:      8.6.10

%description common
 This package contains the common system configuration and scripts responsible for loading the vmblock kernel module.  The vmblock module is used by vmware-user to block file access to files that are in the process of being copied from host to guest or guest to host (such as a drag and drop operation between a host and a guest).

%package kmp-%{type}
Summary:      The vmblock kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmblock-common
Requires:     vmware-tools-foundation >= 0:8.6.10
Provides:     vmware-tools-vmblock-kmp
Release:      %{kversionreltag}.1.el3
Requires: vmware-tools-core = %{?epoch:%{epoch}:}8.6.10

%description kmp-%{type}
 This package contains a pre-compiled vmblock module for use with the %{kernel_version} kernel.   The vmblock module is used by vmware-user to block file access to files that are in the process of being copied from host to guest or guest to host (such as a drag and drop operation between a host and a guest).

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmblock stop
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%pre common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmblock ]; then
      /sbin/chkconfig vmblock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vmblock
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VMBLOCK_NAME
fi

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmblock ]; then
      /sbin/chkconfig vmblock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vmblock
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VMBLOCK_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,rhel,3 --dbAddAnswer VMBLOCK_NAME,vmblock
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-config.pl --os=linux,rhel,3 --toConfigure=vmblock
if [ -e /etc/init.d/vmblock ]; then
   /sbin/chkconfig vmblock on
fi

%post kmp-%{type}
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/%{name}/vmblock.o

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*EL//g'`
if [ -z "$kmodType" ]; then
   kmodType=up
fi
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmblock start
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmblock ]; then
      /sbin/chkconfig vmblock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vmblock
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VMBLOCK_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmblock stop
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-config.pl
/etc/rc.d/init.d/vmblock

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/%{name}/vmblock.o
